@@ -1,6 +1,6 @@
 # Copyright 2010 Jacob Kaplan-Moss
 
-# Copyright 2011 OpenStack Foundation
+# Copyright 2011 OpenStack LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -29,7 +29,7 @@ class Certificate(base.Resource):
                          len(self.data))
 
 
-class CertificateManager(base.Manager):
+class CertificateManager(base.ManagerWithFind):
     """
     Manage :class:`Certificate` resources.
     """
@@ -37,7 +37,7 @@ class CertificateManager(base.Manager):
 
     def create(self):
         """
-        Create a x509 certificate for a user in tenant.
+        Create a x509 certificates for a user in tenant.
         """
         return self._create('/os-certificates', {}, 'certificate')
 
