@@ -1,4 +1,4 @@
-# Copyright 2012 OpenStack Foundation
+# Copyright 2012 OpenStack LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -19,7 +19,7 @@ from novaclient import base
 
 
 class Cloudpipe(base.Resource):
-    """A cloudpipe instance is a VPN attached to a project's VLAN."""
+    """A cloudpipe instance is a VPN attached to a proejct's VLAN."""
 
     def __repr__(self):
         return "<Cloudpipe: %s>" % self.project_id
@@ -35,7 +35,7 @@ class CloudpipeManager(base.ManagerWithFind):
         """
         Launch a cloudpipe instance.
 
-        :param project: UUID of the project (tenant) for the cloudpipe
+        :param project: name of the project for the cloudpipe
         """
         body = {'cloudpipe': {'project_id': project}}
         return self._create('/os-cloudpipe', body, 'instance_id',
@@ -46,16 +46,3 @@ class CloudpipeManager(base.ManagerWithFind):
         Get a list of cloudpipe instances.
         """
         return self._list('/os-cloudpipe', 'cloudpipes')
-
-    def update(self, address, port):
-        """
-        Update VPN address and port for all networks associated
-        with the project defined by authentication
-
-        :param address: IP address
-        :param port: Port number
-        """
-
-        body = {'configure_project': {'vpn_ip': address,
-                                      'vpn_port': port}}
-        self._update("/os-cloudpipe/configure-project", body)
