@@ -1,14 +1,20 @@
-import copy
+import httplib2
 import json
 import mock
 
-import requests
-
 from novaclient.v1_1 import client
 from novaclient import exceptions
 from tests import utils
 
 
+def to_http_response(resp_dict):
+    """Converts dict of response attributes to httplib response."""
+    resp = httplib2.Response(resp_dict)
+    for k, v in resp_dict['headers'].items():
+        resp[k] = v
+    return resp
+
+
 class AuthenticateAgainstKeystoneTests(utils.TestCase):
     def test_authenticate_success(self):
         cs = client.Client("username", "password", "project_id",
@@ -18,9 +24,6 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                 "token": {
                     "expires": "12345",
                     "id": "FAKE_ID",
-                    "tenant": {
-                        "id": "FAKE_TENANT_ID",
-                    }
                 },
                 "serviceCatalog": [
                     {
@@ -37,14 +40,15 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                 ],
             },
         }
-        auth_response = utils.TestResponse({
-            "status_code": 200,
-            "text": json.dumps(resp),
-        })
+        auth_response = httplib2.Response({
+            "status": 200,
+            "body": json.dumps(resp),
+            })
 
-        mock_request = mock.Mock(return_value=(auth_response))
+        mock_request = mock.Mock(return_value=(auth_response,
+                                               json.dumps(resp)))
 
-        @mock.patch.object(requests, "request", mock_request)
+        @mock.patch.object(httplib2.Http, "request", mock_request)
         def test_auth_call():
             cs.client.authenticate()
             headers = {
@@ -63,13 +67,9 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
             }
 
             token_url = cs.client.auth_url + "/tokens"
-            mock_request.assert_called_with(
-                "POST",
-                token_url,
-                headers=headers,
-                data=json.dumps(body),
-                allow_redirects=True,
-                **self.TEST_REQUEST_BASE)
+            mock_request.assert_called_with(token_url, "POST",
+                                            headers=headers,
+                                            body=json.dumps(body))
 
             endpoints = resp["access"]["serviceCatalog"][0]['endpoints']
             public_url = endpoints[0]["publicURL"].rstrip('/')
@@ -83,14 +83,15 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
         cs = client.Client("username", "password", "project_id",
                            "auth_url/v2.0")
         resp = {"unauthorized": {"message": "Unauthorized", "code": "401"}}
-        auth_response = utils.TestResponse({
-            "status_code": 401,
-            "text": json.dumps(resp),
-        })
+        auth_response = httplib2.Response({
+            "status": 401,
+            "body": json.dumps(resp),
+            })
 
-        mock_request = mock.Mock(return_value=(auth_response))
+        mock_request = mock.Mock(return_value=(auth_response,
+                                               json.dumps(resp)))
 
-        @mock.patch.object(requests, "request", mock_request)
+        @mock.patch.object(httplib2.Http, "request", mock_request)
         def test_auth_call():
             self.assertRaises(exceptions.Unauthorized, cs.client.authenticate)
 
@@ -104,9 +105,6 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                 "token": {
                     "expires": "12345",
                     "id": "FAKE_ID",
-                    "tenant": {
-                        "id": "FAKE_TENANT_ID",
-                    }
                 },
                 "serviceCatalog": [
                     {
@@ -126,28 +124,29 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
         correct_response = json.dumps(dict_correct_response)
         dict_responses = [
             {"headers": {'location':'http://127.0.0.1:5001'},
-             "status_code": 305,
-             "text": "Use proxy"},
+             "status": 305,
+             "body": "Use proxy"},
             # Configured on admin port, nova redirects to v2.0 port.
             # When trying to connect on it, keystone auth succeed by v1.0
             # protocol (through headers) but tokens are being returned in
             # body (looks like keystone bug). Leaved for compatibility.
             {"headers": {},
-             "status_code": 200,
-             "text": correct_response},
+             "status": 200,
+             "body": correct_response},
             {"headers": {},
-             "status_code": 200,
-             "text": correct_response}
+             "status": 200,
+             "body": correct_response}
         ]
 
-        responses = [(utils.TestResponse(resp)) for resp in dict_responses]
+        responses = [(to_http_response(resp), resp['body']) \
+                        for resp in dict_responses]
 
         def side_effect(*args, **kwargs):
             return responses.pop(0)
 
         mock_request = mock.Mock(side_effect=side_effect)
 
-        @mock.patch.object(requests, "request", mock_request)
+        @mock.patch.object(httplib2.Http, "request", mock_request)
         def test_auth_call():
             cs.client.authenticate()
             headers = {
@@ -166,14 +165,9 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
             }
 
             token_url = cs.client.auth_url + "/tokens"
-            kwargs = copy.copy(self.TEST_REQUEST_BASE)
-            kwargs['headers'] = headers
-            kwargs['data'] = json.dumps(body)
-            mock_request.assert_called_with(
-                "POST",
-                token_url,
-                allow_redirects=True,
-                **kwargs)
+            mock_request.assert_called_with(token_url, "POST",
+                                            headers=headers,
+                                            body=json.dumps(body))
 
             resp = dict_correct_response
             endpoints = resp["access"]["serviceCatalog"][0]['endpoints']
@@ -192,9 +186,6 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                 "token": {
                     "expires": "12345",
                     "id": "FAKE_ID",
-                    "tenant": {
-                        "id": "FAKE_TENANT_ID",
-                    }
                 },
                 "serviceCatalog": [
                     {
@@ -223,14 +214,15 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
                 ],
             },
         }
-        auth_response = utils.TestResponse({
-            "status_code": 200,
-            "text": json.dumps(resp),
-        })
+        auth_response = httplib2.Response({
+            "status": 200,
+            "body": json.dumps(resp),
+            })
 
-        mock_request = mock.Mock(return_value=(auth_response))
+        mock_request = mock.Mock(return_value=(auth_response,
+                                               json.dumps(resp)))
 
-        @mock.patch.object(requests, "request", mock_request)
+        @mock.patch.object(httplib2.Http, "request", mock_request)
         def test_auth_call():
             self.assertRaises(exceptions.AmbiguousEndpoints,
                               cs.client.authenticate)
@@ -241,17 +233,15 @@ class AuthenticateAgainstKeystoneTests(utils.TestCase):
 class AuthenticationTests(utils.TestCase):
     def test_authenticate_success(self):
         cs = client.Client("username", "password", "project_id", "auth_url")
-        management_url = 'https://localhost/v1.1/443470'
-        auth_response = utils.TestResponse({
-            'status_code': 204,
-            'headers': {
-                'x-server-management-url': management_url,
-                'x-auth-token': '1b751d74-de0c-46ae-84f0-915744b582d1',
-            },
+        management_url = 'https://servers.api.rackspacecloud.com/v1.1/443470'
+        auth_response = httplib2.Response({
+            'status': 204,
+            'x-server-management-url': management_url,
+            'x-auth-token': '1b751d74-de0c-46ae-84f0-915744b582d1',
         })
-        mock_request = mock.Mock(return_value=(auth_response))
+        mock_request = mock.Mock(return_value=(auth_response, None))
 
-        @mock.patch.object(requests, "request", mock_request)
+        @mock.patch.object(httplib2.Http, "request", mock_request)
         def test_auth_call():
             cs.client.authenticate()
             headers = {
@@ -261,25 +251,21 @@ class AuthenticationTests(utils.TestCase):
                 'X-Auth-Project-Id': 'project_id',
                 'User-Agent': cs.client.USER_AGENT
             }
-            mock_request.assert_called_with(
-                "GET",
-                cs.client.auth_url,
-                headers=headers,
-                **self.TEST_REQUEST_BASE)
-
+            mock_request.assert_called_with(cs.client.auth_url, 'GET',
+                                            headers=headers)
             self.assertEqual(cs.client.management_url,
-                             auth_response.headers['x-server-management-url'])
+                             auth_response['x-server-management-url'])
             self.assertEqual(cs.client.auth_token,
-                             auth_response.headers['x-auth-token'])
+                             auth_response['x-auth-token'])
 
         test_auth_call()
 
     def test_authenticate_failure(self):
         cs = client.Client("username", "password", "project_id", "auth_url")
-        auth_response = utils.TestResponse({'status_code': 401})
-        mock_request = mock.Mock(return_value=(auth_response))
+        auth_response = httplib2.Response({'status': 401})
+        mock_request = mock.Mock(return_value=(auth_response, None))
 
-        @mock.patch.object(requests, "request", mock_request)
+        @mock.patch.object(httplib2.Http, "request", mock_request)
         def test_auth_call():
             self.assertRaises(exceptions.Unauthorized, cs.client.authenticate)
 
